@@ -16,8 +16,8 @@ class Cli(object):
         )
         self.config = ConfigParser(config_file)
         self.name = self.config.get("cli", "name", "Freeldep")
-        self.version = self.config.get("cli", "version")
-        self.description = self.config.get("cli", "description")
+        self.version = self.config.get("cli", "version", "latest")
+        self.description = self.config.get("cli", "description", "Serverless Infrastructure Deployment")
         self.aws_profile = aws_profile
 
     def require_cloud_access(self):
