@@ -4,19 +4,19 @@ import os
 import pytest
 import yaml
 
-from cli.modules.utils import delete_deployer
-from cli.modules.utils import execute_script
-from cli.modules.utils import file_exists
-from cli.modules.utils import get_workflow_id
-from cli.modules.utils import list_files
-from cli.modules.utils import load_deployer
-from cli.modules.utils import mkdir
-from cli.modules.utils import read_json
-from cli.modules.utils import read_yaml
-from cli.modules.utils import save_deployer
-from cli.modules.utils import save_json
-from cli.modules.utils import shorten_expr
-from cli.modules.utils import valid_expr
+from freeldep.modules.utils import delete_deployer
+from freeldep.modules.utils import execute_script
+from freeldep.modules.utils import file_exists
+from freeldep.modules.utils import get_workflow_id
+from freeldep.modules.utils import list_files
+from freeldep.modules.utils import load_deployer
+from freeldep.modules.utils import mkdir
+from freeldep.modules.utils import read_json
+from freeldep.modules.utils import read_yaml
+from freeldep.modules.utils import save_deployer
+from freeldep.modules.utils import save_json
+from freeldep.modules.utils import shorten_expr
+from freeldep.modules.utils import valid_expr
 
 TEMP_FOLDER = "/tmp/"
 
@@ -55,7 +55,7 @@ def test_list_files():
     for f in files:
         print(f)
         assert os.path.isfile(FOLDER + f)
-    assert len(files) == 1
+    assert len(files) == 3
 
 
 def test_save_json():
@@ -126,6 +126,7 @@ def test_execute_script():
 
 def test_get_workflow_id(deployer, config):
     workflow_name = "test-workflow"
-    expected_aws_arn = f"arn:aws:states:region:123456789012:stateMachine:{workflow_name}"
+    expected_aws_arn = (
+        f"arn:aws:states:region:123456789012:stateMachine:{workflow_name}"
+    )
     assert get_workflow_id("test-workflow", config) == expected_aws_arn
-
