@@ -3,7 +3,7 @@ import os
 import click
 import pytest
 
-from cli.config import ConfigParser
+from freeldep.config import ConfigParser
 
 
 def test_config_error():
@@ -21,7 +21,9 @@ def test_config_filename():
 
 def test_config_env():
     os.environ["FREELDEP_CONFIG"] = ""
-    os.environ["FREELDEP_HOME"] = "./cli/"
+    os.environ["FREELDEP_HOME"] = "./freeldep/"
+    ConfigParser("")
+    os.environ["FREELDEP_HOME"] = "./freeldep"
     ConfigParser("")
 
 
